==> haskell-digest-0.0.1.7-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   digest
version:                0.0.1.7
visibility:             public
id:                     digest-0.0.1.7-1ULzTOd58BH2MSqV7QWMT
key:                    digest-0.0.1.7-1ULzTOd58BH2MSqV7QWMT
license:                BSD-2-Clause
copyright:              (c) 2009 Eugene Kirpichov
maintainer:             Eugene Kirpichov <ekirpichov@gmail.com>
author:                 Eugene Kirpichov <ekirpichov@gmail.com>
stability:              provisional
synopsis:               Various hashes for bytestrings; CRC32 and Adler32 for now.
description:
    This package provides efficient hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:               Cryptography
abi:                    e53a984484ec86fc7c369fec69e3bb46
exposed:                True
exposed-modules:        Data.Digest.Adler32 Data.Digest.CRC32
import-dirs:            /usr/lib/ghc-9.4.8/site-local/digest-0.0.1.7
library-dirs:           /usr/lib/ghc-9.4.8/site-local/digest-0.0.1.7
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/digest-0.0.1.7
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-digest
hs-libraries:           HSdigest-0.0.1.7-1ULzTOd58BH2MSqV7QWMT
extra-libraries:        z
extra-libraries-static: z
includes:               zlib.h
depends:                base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:     /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:           /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digest-0.0.2.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   digest
version:                0.0.2.0
visibility:             public
id:                     digest-0.0.2.0-EftUkDcFXHWPGQislPxLu
key:                    digest-0.0.2.0-EftUkDcFXHWPGQislPxLu
license:                BSD-2-Clause
copyright:              (c) 2009 Eugene Kirpichov
maintainer:             Eugene Kirpichov <ekirpichov@gmail.com>
author:                 Eugene Kirpichov <ekirpichov@gmail.com>
stability:              provisional
synopsis:               CRC32 and Adler32 hashes for bytestrings
description:
    This package provides efficient hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:               Cryptography
abi:                    09d9e6ed44fe5ee80ce9e20de5599a25
exposed:                True
exposed-modules:
    Data.Digest.Adler32 Data.Digest.CRC32 Data.Digest.CRC32C

import-dirs:            /usr/lib/ghc-9.4.8/site-local/digest-0.0.2.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/digest-0.0.2.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/digest-0.0.2.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-digest
hs-libraries:           HSdigest-0.0.2.0-EftUkDcFXHWPGQislPxLu
extra-libraries:        z
extra-libraries-static: z
includes:               zlib.h
depends:                base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:     /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:           /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
